# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/auth/v1beta1/auth.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xd3\x01\n\x0b\x42\x61seAccount\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12T\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB-\xea\xde\x1f\x14public_key,omitempty\xf2\xde\x1f\x11yaml:\"public_key\"\x12\x31\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04\x42\x19\xf2\xde\x1f\x15yaml:\"account_number\"\x12\x10\n\x08sequence\x18\x04 \x01(\x04:\x18\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xd2\xb4-\x08\x41\x63\x63ountI\"\xa3\x01\n\rModuleAccount\x12S\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t:\x1a\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xd2\xb4-\x0eModuleAccountI\"\xff\x02\n\x06Params\x12;\n\x13max_memo_characters\x18\x01 \x01(\x04\x42\x1e\xf2\xde\x1f\x1ayaml:\"max_memo_characters\"\x12-\n\x0ctx_sig_limit\x18\x02 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"tx_sig_limit\"\x12?\n\x15tx_size_cost_per_byte\x18\x03 \x01(\x04\x42 \xf2\xde\x1f\x1cyaml:\"tx_size_cost_per_byte\"\x12[\n\x17sig_verify_cost_ed25519\x18\x04 \x01(\x04\x42:\xe2\xde\x1f\x14SigVerifyCostED25519\xf2\xde\x1f\x1eyaml:\"sig_verify_cost_ed25519\"\x12\x61\n\x19sig_verify_cost_secp256k1\x18\x05 \x01(\x04\x42>\xe2\xde\x1f\x16SigVerifyCostSecp256k1\xf2\xde\x1f yaml:\"sig_verify_cost_secp256k1\":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _BASEACCOUNT.fields_by_name['pub_key']._options = None
  _BASEACCOUNT.fields_by_name['pub_key']._serialized_options = b'\352\336\037\024public_key,omitempty\362\336\037\021yaml:\"public_key\"'
  _BASEACCOUNT.fields_by_name['account_number']._options = None
  _BASEACCOUNT.fields_by_name['account_number']._serialized_options = b'\362\336\037\025yaml:\"account_number\"'
  _BASEACCOUNT._options = None
  _BASEACCOUNT._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000\322\264-\010AccountI'
  _MODULEACCOUNT.fields_by_name['base_account']._options = None
  _MODULEACCOUNT.fields_by_name['base_account']._serialized_options = b'\320\336\037\001\362\336\037\023yaml:\"base_account\"'
  _MODULEACCOUNT._options = None
  _MODULEACCOUNT._serialized_options = b'\210\240\037\000\230\240\037\000\322\264-\016ModuleAccountI'
  _PARAMS.fields_by_name['max_memo_characters']._options = None
  _PARAMS.fields_by_name['max_memo_characters']._serialized_options = b'\362\336\037\032yaml:\"max_memo_characters\"'
  _PARAMS.fields_by_name['tx_sig_limit']._options = None
  _PARAMS.fields_by_name['tx_sig_limit']._serialized_options = b'\362\336\037\023yaml:\"tx_sig_limit\"'
  _PARAMS.fields_by_name['tx_size_cost_per_byte']._options = None
  _PARAMS.fields_by_name['tx_size_cost_per_byte']._serialized_options = b'\362\336\037\034yaml:\"tx_size_cost_per_byte\"'
  _PARAMS.fields_by_name['sig_verify_cost_ed25519']._options = None
  _PARAMS.fields_by_name['sig_verify_cost_ed25519']._serialized_options = b'\342\336\037\024SigVerifyCostED25519\362\336\037\036yaml:\"sig_verify_cost_ed25519\"'
  _PARAMS.fields_by_name['sig_verify_cost_secp256k1']._options = None
  _PARAMS.fields_by_name['sig_verify_cost_secp256k1']._serialized_options = b'\342\336\037\026SigVerifyCostSecp256k1\362\336\037 yaml:\"sig_verify_cost_secp256k1\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001\230\240\037\000'
  _BASEACCOUNT._serialized_start=132
  _BASEACCOUNT._serialized_end=343
  _MODULEACCOUNT._serialized_start=346
  _MODULEACCOUNT._serialized_end=509
  _PARAMS._serialized_start=512
  _PARAMS._serialized_end=895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.exchange.v1beta1 import genesis_pb2 as injective_dot_exchange_dot_v1beta1_dot_genesis__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/exchange/v1beta1/query.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a(injective/exchange/v1beta1/genesis.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"6\n\nSubaccount\x12\x0e\n\x06trader\x18\x01 \x01(\t\x12\x18\n\x10subaccount_nonce\x18\x02 \x01(\r\"H\n\x1cQuerySubaccountOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xaa\x01\n\x1dQuerySubaccountOrdersResponse\x12\x43\n\nbuy_orders\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\x12\x44\n\x0bsell_orders\x18\x02 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\"\x94\x01\n%SubaccountOrderbookMetadataWithMarket\x12I\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.injective.exchange.v1beta1.SubaccountOrderbookMetadata\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\r\n\x05isBuy\x18\x03 \x01(\x08\"\x1c\n\x1aQueryExchangeParamsRequest\"W\n\x1bQueryExchangeParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"y\n\x1eQuerySubaccountDepositsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12@\n\nsubaccount\x18\x02 \x01(\x0b\x32&.injective.exchange.v1beta1.SubaccountB\x04\xc8\xde\x1f\x01\"\xd4\x01\n\x1fQuerySubaccountDepositsResponse\x12[\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32I.injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry\x1aT\n\rDepositsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit:\x02\x38\x01\"\x1e\n\x1cQueryExchangeBalancesRequest\"\\\n\x1dQueryExchangeBalancesResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\".\n\x1bQueryAggregateVolumeRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"c\n\x1cQueryAggregateVolumeResponse\x12\x43\n\x11\x61ggregate_volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"D\n\x1cQueryAggregateVolumesRequest\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\"\xc8\x01\n\x1dQueryAggregateVolumesResponse\x12[\n\x19\x61ggregate_account_volumes\x18\x01 \x03(\x0b\x32\x38.injective.exchange.v1beta1.AggregateAccountVolumeRecord\x12J\n\x18\x61ggregate_market_volumes\x18\x02 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"6\n!QueryAggregateMarketVolumeRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"d\n\"QueryAggregateMarketVolumeResponse\x12>\n\x06volume\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.VolumeRecordB\x04\xc8\xde\x1f\x00\")\n\x18QueryDenomDecimalRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\",\n\x19QueryDenomDecimalResponse\x12\x0f\n\x07\x64\x65\x63imal\x18\x01 \x01(\x04\"+\n\x19QueryDenomDecimalsRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\"e\n\x1aQueryDenomDecimalsResponse\x12G\n\x0e\x64\x65nom_decimals\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimalsB\x04\xc8\xde\x1f\x00\"8\n\"QueryAggregateMarketVolumesRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"`\n#QueryAggregateMarketVolumesResponse\x12\x39\n\x07volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"E\n\x1dQuerySubaccountDepositRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"W\n\x1eQuerySubaccountDepositResponse\x12\x35\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit\")\n\x17QuerySpotMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"S\n\x18QuerySpotMarketsResponse\x12\x37\n\x07markets\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"+\n\x16QuerySpotMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"Q\n\x17QuerySpotMarketResponse\x12\x36\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"=\n\x19QuerySpotOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x97\x01\n\x1aQuerySpotOrderbookResponse\x12;\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\x12<\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\"`\n\x1eQuerySpotOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"d\n\x1fQuerySpotOrdersByHashesResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"H\n\x1cQueryTraderSpotOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"\xfd\x01\n\x15TrimmedSpotLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\r\n\x05isBuy\x18\x04 \x01(\x08\x12\x12\n\norder_hash\x18\x05 \x01(\t\"b\n\x1dQueryTraderSpotOrdersResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"3\n\x1eQuerySpotMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xf5\x01\n\x1fQuerySpotMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"9\n$QueryDerivativeMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xfb\x01\n%QueryDerivativeMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"C\n\x1fQueryDerivativeOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x9d\x01\n QueryDerivativeOrderbookResponse\x12;\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\x12<\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\"\xf2\x02\n.QueryTraderSpotOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cquote_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\x08strategy\x18\x05 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xb3\x02\n4QueryTraderDerivativeOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x44\n\x0cquote_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\x08strategy\x18\x04 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"N\n\"QueryTraderDerivativeOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"\xce\x02\n\x1bTrimmedDerivativeLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x12\n\norder_hash\x18\x06 \x01(\t\"n\n#QueryTraderDerivativeOrdersResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"f\n$QueryDerivativeOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"p\n%QueryDerivativeOrdersByHashesResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"/\n\x1dQueryDerivativeMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x8d\x01\n\nPriceLevel\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa6\x01\n\x14PerpetualMarketState\x12\x44\n\x0bmarket_info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfo\x12H\n\x0c\x66unding_info\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFunding\"\xb9\x02\n\x14\x46ullDerivativeMarket\x12<\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarket\x12J\n\x0eperpetual_info\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.PerpetualMarketStateH\x00\x12K\n\x0c\x66utures_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoH\x00\x12\x42\n\nmark_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x06\n\x04info\"c\n\x1eQueryDerivativeMarketsResponse\x12\x41\n\x07markets\x18\x01 \x03(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"1\n\x1cQueryDerivativeMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"a\n\x1dQueryDerivativeMarketResponse\x12@\n\x06market\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"8\n#QueryDerivativeMarketAddressRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"N\n$QueryDerivativeMarketAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"9\n QuerySubaccountTradeNonceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"8\n\x1fQuerySubaccountPositionsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"R\n&QuerySubaccountPositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"[\n/QuerySubaccountEffectivePositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"<\n#QuerySubaccountOrderMetadataRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"g\n QuerySubaccountPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"d\n\'QuerySubaccountPositionInMarketResponse\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.PositionB\x04\xc8\xde\x1f\x01\"\xf5\x01\n\x11\x45\x66\x66\x65\x63tivePosition\x12\x0f\n\x07is_long\x18\x01 \x01(\x08\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x65ntry_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x65\x66\x66\x65\x63tive_margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"v\n0QuerySubaccountEffectivePositionInMarketResponse\x12\x42\n\x05state\x18\x01 \x01(\x0b\x32-.injective.exchange.v1beta1.EffectivePositionB\x04\xc8\xde\x1f\x01\"4\n\x1fQueryPerpetualMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"g\n QueryPerpetualMarketInfoResponse\x12\x43\n\x04info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00\"8\n#QueryExpiryFuturesMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"o\n$QueryExpiryFuturesMarketInfoResponse\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x00\"7\n\"QueryPerpetualMarketFundingRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"n\n#QueryPerpetualMarketFundingResponse\x12G\n\x05state\x18\x01 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00\"\x81\x01\n$QuerySubaccountOrderMetadataResponse\x12Y\n\x08metadata\x18\x01 \x03(\x0b\x32\x41.injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarketB\x04\xc8\xde\x1f\x00\"2\n!QuerySubaccountTradeNonceResponse\x12\r\n\x05nonce\x18\x01 \x01(\r\"\x19\n\x17QueryModuleStateRequest\"S\n\x18QueryModuleStateResponse\x12\x37\n\x05state\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.GenesisState\"\x17\n\x15QueryPositionsRequest\"]\n\x16QueryPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"Q\n\x1dQueryTradeRewardPointsRequest\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x02 \x01(\x03\"u\n\x1eQueryTradeRewardPointsResponse\x12S\n\x1b\x61\x63\x63ount_trade_reward_points\x18\x01 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"!\n\x1fQueryTradeRewardCampaignRequest\"\xf3\x03\n QueryTradeRewardCampaignResponse\x12[\n\x1ctrading_reward_campaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12]\n%trading_reward_pool_campaign_schedule\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Q\n\x19total_trade_reward_points\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x65\n-pending_trading_reward_pool_campaign_schedule\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Y\n!pending_total_trade_reward_points\x18\x05 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"2\n\x1fQueryIsOptedOutOfRewardsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"8\n QueryIsOptedOutOfRewardsResponse\x12\x14\n\x0cis_opted_out\x18\x01 \x01(\x08\"\'\n%QueryOptedOutOfRewardsAccountsRequest\":\n&QueryOptedOutOfRewardsAccountsResponse\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\"5\n\"QueryFeeDiscountAccountInfoRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"\xc5\x01\n#QueryFeeDiscountAccountInfoResponse\x12\x12\n\ntier_level\x18\x01 \x01(\x04\x12\x45\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfo\x12\x43\n\x0b\x61\x63\x63ount_ttl\x18\x03 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTL\"!\n\x1fQueryFeeDiscountScheduleRequest\"r\n QueryFeeDiscountScheduleResponse\x12N\n\x15\x66\x65\x65_discount_schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\"4\n\x1dQueryBalanceMismatchesRequest\x12\x13\n\x0b\x64ust_factor\x18\x01 \x01(\x03\"\x8a\x03\n\x0f\x42\x61lanceMismatch\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05total\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0e\x65xpected_total\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\ndifference\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"i\n\x1eQueryBalanceMismatchesResponse\x12G\n\x12\x62\x61lance_mismatches\x18\x01 \x03(\x0b\x32+.injective.exchange.v1beta1.BalanceMismatch\"%\n#QueryBalanceWithBalanceHoldsRequest\"\x84\x02\n\x15\x42\x61lanceWithMarginHold\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05total\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"}\n$QueryBalanceWithBalanceHoldsResponse\x12U\n\x1a\x62\x61lance_with_balance_holds\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.BalanceWithMarginHold\"\'\n%QueryFeeDiscountTierStatisticsRequest\",\n\rTierStatistic\x12\x0c\n\x04tier\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"g\n&QueryFeeDiscountTierStatisticsResponse\x12=\n\nstatistics\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.TierStatistic\"\x17\n\x15MitoVaultInfosRequest\"\x80\x01\n\x16MitoVaultInfosResponse\x12\x18\n\x10master_addresses\x18\x01 \x03(\t\x12\x1c\n\x14\x64\x65rivative_addresses\x18\x02 \x03(\t\x12\x16\n\x0espot_addresses\x18\x03 \x03(\t\x12\x16\n\x0e\x63w20_addresses\x18\x04 \x03(\t\"<\n\x1dQueryMarketIDFromVaultRequest\x12\x1b\n\x13vault_subaccount_id\x18\x01 \x01(\t\"3\n\x1eQueryMarketIDFromVaultResponse\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"7\n\"QueryHistoricalTradeRecordsRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"f\n#QueryHistoricalTradeRecordsResponse\x12?\n\rtrade_records\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecords\"y\n\x13TradeHistoryOptions\x12\x1a\n\x12trade_grouping_sec\x18\x01 \x01(\x04\x12\x0f\n\x07max_age\x18\x02 \x01(\x04\x12\x1b\n\x13include_raw_history\x18\x04 \x01(\x08\x12\x18\n\x10include_metadata\x18\x05 \x01(\x08\"\x81\x01\n\x1cQueryMarketVolatilityRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12N\n\x15trade_history_options\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.TradeHistoryOptions\"\xe5\x01\n\x1dQueryMarketVolatilityResponse\x12>\n\nvolatility\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatistics\x12<\n\x0braw_history\x18\x03 \x03(\x0b\x32\'.injective.exchange.v1beta1.TradeRecord\"+\n\x19QueryBinaryMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"^\n\x1aQueryBinaryMarketsResponse\x12@\n\x07markets\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarket\"Y\n-QueryTraderDerivativeConditionalOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xf6\x02\n!TrimmedDerivativeConditionalOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0ctriggerPrice\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x1c\n\x07isLimit\x18\x06 \x01(\x08\x42\x0b\xea\xde\x1f\x07isLimit\x12\x12\n\norder_hash\x18\x07 \x01(\t\"\x7f\n.QueryTraderDerivativeConditionalOrdersResponse\x12M\n\x06orders\x18\x01 \x03(\x0b\x32=.injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder\"C\n.QueryMarketAtomicExecutionFeeMultiplierRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"u\n/QueryMarketAtomicExecutionFeeMultiplierResponse\x12\x42\n\nmultiplier\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00*V\n\x14\x43\x61ncellationStrategy\x12\x14\n\x10UnspecifiedOrder\x10\x00\x12\x13\n\x0f\x46romWorstToBest\x10\x01\x12\x13\n\x0f\x46romBestToWorst\x10\x02\x32\xc5Y\n\x05Query\x12\xba\x01\n\x13QueryExchangeParams\x12\x36.injective.exchange.v1beta1.QueryExchangeParamsRequest\x1a\x37.injective.exchange.v1beta1.QueryExchangeParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v1beta1/exchangeParams\x12\xce\x01\n\x12SubaccountDeposits\x12:.injective.exchange.v1beta1.QuerySubaccountDepositsRequest\x1a;.injective.exchange.v1beta1.QuerySubaccountDepositsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/exchange/subaccountDeposits\x12\xca\x01\n\x11SubaccountDeposit\x12\x39.injective.exchange.v1beta1.QuerySubaccountDepositRequest\x1a:.injective.exchange.v1beta1.QuerySubaccountDepositResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/exchange/subaccountDeposit\x12\xc6\x01\n\x10\x45xchangeBalances\x12\x38.injective.exchange.v1beta1.QueryExchangeBalancesRequest\x1a\x39.injective.exchange.v1beta1.QueryExchangeBalancesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/exchangeBalances\x12\xcc\x01\n\x0f\x41ggregateVolume\x12\x37.injective.exchange.v1beta1.QueryAggregateVolumeRequest\x1a\x38.injective.exchange.v1beta1.QueryAggregateVolumeResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}\x12\xc6\x01\n\x10\x41ggregateVolumes\x12\x38.injective.exchange.v1beta1.QueryAggregateVolumesRequest\x1a\x39.injective.exchange.v1beta1.QueryAggregateVolumesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/aggregateVolumes\x12\xe6\x01\n\x15\x41ggregateMarketVolume\x12=.injective.exchange.v1beta1.QueryAggregateMarketVolumeRequest\x1a>.injective.exchange.v1beta1.QueryAggregateMarketVolumeResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}\x12\xde\x01\n\x16\x41ggregateMarketVolumes\x12>.injective.exchange.v1beta1.QueryAggregateMarketVolumesRequest\x1a?.injective.exchange.v1beta1.QueryAggregateMarketVolumesResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes\x12\xbf\x01\n\x0c\x44\x65nomDecimal\x12\x34.injective.exchange.v1beta1.QueryDenomDecimalRequest\x1a\x35.injective.exchange.v1beta1.QueryDenomDecimalResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}\x12\xbb\x01\n\rDenomDecimals\x12\x35.injective.exchange.v1beta1.QueryDenomDecimalsRequest\x1a\x36.injective.exchange.v1beta1.QueryDenomDecimalsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/exchange/denom_decimals\x12\xaa\x01\n\x0bSpotMarkets\x12\x33.injective.exchange.v1beta1.QuerySpotMarketsRequest\x1a\x34.injective.exchange.v1beta1.QuerySpotMarketsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/spot/markets\x12\xb3\x01\n\nSpotMarket\x12\x32.injective.exchange.v1beta1.QuerySpotMarketRequest\x1a\x33.injective.exchange.v1beta1.QuerySpotMarketResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/spot/markets/{market_id}\x12\xbe\x01\n\rSpotOrderbook\x12\x35.injective.exchange.v1beta1.QuerySpotOrderbookRequest\x1a\x36.injective.exchange.v1beta1.QuerySpotOrderbookResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/spot/orderbook/{market_id}\x12\xd4\x01\n\x10TraderSpotOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}\x12\xe4\x01\n\x12SpotOrdersByHashes\x12:.injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest\x1a;.injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}\x12\xc3\x01\n\x10SubaccountOrders\x12\x38.injective.exchange.v1beta1.QuerySubaccountOrdersRequest\x1a\x39.injective.exchange.v1beta1.QuerySubaccountOrdersResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/orders/{subaccount_id}\x12\xe7\x01\n\x19TraderSpotTransientOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}\x12\xd5\x01\n\x12SpotMidPriceAndTOB\x12:.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest\x1a;.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}\x12\xed\x01\n\x18\x44\x65rivativeMidPriceAndTOB\x12@.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}\x12\xd6\x01\n\x13\x44\x65rivativeOrderbook\x12;.injective.exchange.v1beta1.QueryDerivativeOrderbookRequest\x1a<.injective.exchange.v1beta1.QueryDerivativeOrderbookResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/derivative/orderbook/{market_id}\x12\xec\x01\n\x16TraderDerivativeOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}\x12\xfc\x01\n\x18\x44\x65rivativeOrdersByHashes\x12@.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}\x12\xff\x01\n\x1fTraderDerivativeTransientOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}\x12\xc2\x01\n\x11\x44\x65rivativeMarkets\x12\x39.injective.exchange.v1beta1.QueryDerivativeMarketsRequest\x1a:.injective.exchange.v1beta1.QueryDerivativeMarketsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v1beta1/derivative/markets\x12\xcb\x01\n\x10\x44\x65rivativeMarket\x12\x38.injective.exchange.v1beta1.QueryDerivativeMarketRequest\x1a\x39.injective.exchange.v1beta1.QueryDerivativeMarketResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/derivative/markets/{market_id}\x12\xe7\x01\n\x17\x44\x65rivativeMarketAddress\x12?.injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest\x1a@.injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/derivative/market_address/{market_id}\x12\xd1\x01\n\x14SubaccountTradeNonce\x12<.injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest\x1a=.injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/exchange/{subaccount_id}\x12\xb2\x01\n\x13\x45xchangeModuleState\x12\x33.injective.exchange.v1beta1.QueryModuleStateRequest\x1a\x34.injective.exchange.v1beta1.QueryModuleStateResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/module_state\x12\xa1\x01\n\tPositions\x12\x31.injective.exchange.v1beta1.QueryPositionsRequest\x1a\x32.injective.exchange.v1beta1.QueryPositionsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/exchange/v1beta1/positions\x12\xcf\x01\n\x13SubaccountPositions\x12;.injective.exchange.v1beta1.QuerySubaccountPositionsRequest\x1a<.injective.exchange.v1beta1.QuerySubaccountPositionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/positions/{subaccount_id}\x12\xf0\x01\n\x1aSubaccountPositionInMarket\x12\x42.injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest\x1a\x43.injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}\x12\x95\x02\n#SubaccountEffectivePositionInMarket\x12K.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest\x1aL.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse\"S\x82\xd3\xe4\x93\x02M\x12K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}\x12\xd7\x01\n\x13PerpetualMarketInfo\x12;.injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest\x1a<.injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/perpetual_market_info/{market_id}\x12\xe0\x01\n\x17\x45xpiryFuturesMarketInfo\x12?.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest\x1a@.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/expiry_market_info/{market_id}\x12\xe3\x01\n\x16PerpetualMarketFunding\x12>.injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest\x1a?.injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}\x12\xe0\x01\n\x17SubaccountOrderMetadata\x12?.injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest\x1a@.injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/order_metadata/{subaccount_id}\x12\xc3\x01\n\x11TradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v1beta1/trade_reward_points\x12\xd2\x01\n\x18PendingTradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/pending_trade_reward_points\x12\xcb\x01\n\x13TradeRewardCampaign\x12;.injective.exchange.v1beta1.QueryTradeRewardCampaignRequest\x1a<.injective.exchange.v1beta1.QueryTradeRewardCampaignResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/trade_reward_campaign\x12\xe2\x01\n\x16\x46\x65\x65\x44iscountAccountInfo\x12>.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest\x1a?.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/injective/exchange/v1beta1/fee_discount_account_info/{account}\x12\xcb\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12;.injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest\x1a<.injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/fee_discount_schedule\x12\xd0\x01\n\x11\x42\x61lanceMismatches\x12\x39.injective.exchange.v1beta1.QueryBalanceMismatchesRequest\x1a:.injective.exchange.v1beta1.QueryBalanceMismatchesResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/balance_mismatches/{dust_factor}\x12\xdd\x01\n\x17\x42\x61lanceWithBalanceHolds\x12?.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest\x1a@.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/balances_with_balance_holds\x12\xdf\x01\n\x19\x46\x65\x65\x44iscountTierStatistics\x12\x41.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest\x1a\x42.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/fee_discount_tier_stats\x12\xad\x01\n\x0eMitoVaultInfos\x12\x31.injective.exchange.v1beta1.MitoVaultInfosRequest\x1a\x32.injective.exchange.v1beta1.MitoVaultInfosResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v1beta1/mito_vault_infos\x12\xda\x01\n\x16QueryMarketIDFromVault\x12\x39.injective.exchange.v1beta1.QueryMarketIDFromVaultRequest\x1a:.injective.exchange.v1beta1.QueryMarketIDFromVaultResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/vault_market_id/{vault_subaccount_id}\x12\xd7\x01\n\x16HistoricalTradeRecords\x12>.injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest\x1a?.injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/historical_trade_records\x12\xd7\x01\n\x13IsOptedOutOfRewards\x12;.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest\x1a<.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}\x12\xe5\x01\n\x19OptedOutOfRewardsAccounts\x12\x41.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest\x1a\x42.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/opted_out_of_rewards_accounts\x12\xca\x01\n\x10MarketVolatility\x12\x38.injective.exchange.v1beta1.QueryMarketVolatilityRequest\x1a\x39.injective.exchange.v1beta1.QueryMarketVolatilityResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/market_volatility/{market_id}\x12\xc1\x01\n\x14\x42inaryOptionsMarkets\x12\x35.injective.exchange.v1beta1.QueryBinaryMarketsRequest\x1a\x36.injective.exchange.v1beta1.QueryBinaryMarketsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/binary_options/markets\x12\x99\x02\n!TraderDerivativeConditionalOrders\x12I.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest\x1aJ.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse\"]\x82\xd3\xe4\x93\x02W\x12U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}\x12\xfe\x01\n\"MarketAtomicExecutionFeeMultiplier\x12J.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierRequest\x1aK.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/atomic_order_fee_multiplierBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount']._options = None
  _QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount']._serialized_options = b'\310\336\037\001'
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._options = None
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._serialized_options = b'8\001'
  _QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances']._options = None
  _QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATEMARKETVOLUMERESPONSE.fields_by_name['volume']._options = None
  _QUERYAGGREGATEMARKETVOLUMERESPONSE.fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _QUERYDENOMDECIMALSRESPONSE.fields_by_name['denom_decimals']._options = None
  _QUERYDENOMDECIMALSRESPONSE.fields_by_name['denom_decimals']._serialized_options = b'\310\336\037\000'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['price']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['quantity']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['fillable']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['fillable']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['base_amount']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['base_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['price']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['quantity']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['margin']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['fillable']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['fillable']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['isBuy']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _PRICELEVEL.fields_by_name['price']._options = None
  _PRICELEVEL.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICELEVEL.fields_by_name['quantity']._options = None
  _PRICELEVEL.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _FULLDERIVATIVEMARKET.fields_by_name['mark_price']._options = None
  _FULLDERIVATIVEMARKET.fields_by_name['mark_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _EFFECTIVEPOSITION.fields_by_name['quantity']._options = None
  _EFFECTIVEPOSITION.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EFFECTIVEPOSITION.fields_by_name['entry_price']._options = None
  _EFFECTIVEPOSITION.fields_by_name['entry_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EFFECTIVEPOSITION.fields_by_name['effective_margin']._options = None
  _EFFECTIVEPOSITION.fields_by_name['effective_margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info']._options = None
  _QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info']._options = None
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state']._options = None
  _QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata']._options = None
  _QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _QUERYPOSITIONSRESPONSE.fields_by_name['state']._options = None
  _QUERYPOSITIONSRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYTRADEREWARDPOINTSRESPONSE.fields_by_name['account_trade_reward_points']._options = None
  _QUERYTRADEREWARDPOINTSRESPONSE.fields_by_name['account_trade_reward_points']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['total_trade_reward_points']._options = None
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['total_trade_reward_points']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_total_trade_reward_points']._options = None
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_total_trade_reward_points']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEMISMATCH.fields_by_name['available']._options = None
  _BALANCEMISMATCH.fields_by_name['available']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEMISMATCH.fields_by_name['total']._options = None
  _BALANCEMISMATCH.fields_by_name['total']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEMISMATCH.fields_by_name['balance_hold']._options = None
  _BALANCEMISMATCH.fields_by_name['balance_hold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEMISMATCH.fields_by_name['expected_total']._options = None
  _BALANCEMISMATCH.fields_by_name['expected_total']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEMISMATCH.fields_by_name['difference']._options = None
  _BALANCEMISMATCH.fields_by_name['difference']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEWITHMARGINHOLD.fields_by_name['available']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['available']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEWITHMARGINHOLD.fields_by_name['total']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['total']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BALANCEWITHMARGINHOLD.fields_by_name['balance_hold']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['balance_hold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYMARKETVOLATILITYRESPONSE.fields_by_name['volatility']._options = None
  _QUERYMARKETVOLATILITYRESPONSE.fields_by_name['volatility']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['price']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['quantity']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['margin']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['triggerPrice']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['triggerPrice']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isBuy']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isLimit']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isLimit']._serialized_options = b'\352\336\037\007isLimit'
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE.fields_by_name['multiplier']._options = None
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE.fields_by_name['multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERY.methods_by_name['QueryExchangeParams']._options = None
  _QUERY.methods_by_name['QueryExchangeParams']._serialized_options = b'\202\323\344\223\002,\022*/injective/exchange/v1beta1/exchangeParams'
  _QUERY.methods_by_name['SubaccountDeposits']._options = None
  _QUERY.methods_by_name['SubaccountDeposits']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/exchange/subaccountDeposits'
  _QUERY.methods_by_name['SubaccountDeposit']._options = None
  _QUERY.methods_by_name['SubaccountDeposit']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/exchange/subaccountDeposit'
  _QUERY.methods_by_name['ExchangeBalances']._options = None
  _QUERY.methods_by_name['ExchangeBalances']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/exchangeBalances'
  _QUERY.methods_by_name['AggregateVolume']._options = None
  _QUERY.methods_by_name['AggregateVolume']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}'
  _QUERY.methods_by_name['AggregateVolumes']._options = None
  _QUERY.methods_by_name['AggregateVolumes']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/aggregateVolumes'
  _QUERY.methods_by_name['AggregateMarketVolume']._options = None
  _QUERY.methods_by_name['AggregateMarketVolume']._serialized_options = b'\202\323\344\223\002H\022F/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}'
  _QUERY.methods_by_name['AggregateMarketVolumes']._options = None
  _QUERY.methods_by_name['AggregateMarketVolumes']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes'
  _QUERY.methods_by_name['DenomDecimal']._options = None
  _QUERY.methods_by_name['DenomDecimal']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}'
  _QUERY.methods_by_name['DenomDecimals']._options = None
  _QUERY.methods_by_name['DenomDecimals']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/exchange/denom_decimals'
  _QUERY.methods_by_name['SpotMarkets']._options = None
  _QUERY.methods_by_name['SpotMarkets']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/spot/markets'
  _QUERY.methods_by_name['SpotMarket']._options = None
  _QUERY.methods_by_name['SpotMarket']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/spot/markets/{market_id}'
  _QUERY.methods_by_name['SpotOrderbook']._options = None
  _QUERY.methods_by_name['SpotOrderbook']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/spot/orderbook/{market_id}'
  _QUERY.methods_by_name['TraderSpotOrders']._options = None
  _QUERY.methods_by_name['TraderSpotOrders']._serialized_options = b'\202\323\344\223\002E\022C/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['SpotOrdersByHashes']._options = None
  _QUERY.methods_by_name['SpotOrdersByHashes']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['SubaccountOrders']._options = None
  _QUERY.methods_by_name['SubaccountOrders']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/orders/{subaccount_id}'
  _QUERY.methods_by_name['TraderSpotTransientOrders']._options = None
  _QUERY.methods_by_name['TraderSpotTransientOrders']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['SpotMidPriceAndTOB']._options = None
  _QUERY.methods_by_name['SpotMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}'
  _QUERY.methods_by_name['DerivativeMidPriceAndTOB']._options = None
  _QUERY.methods_by_name['DerivativeMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002F\022D/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}'
  _QUERY.methods_by_name['DerivativeOrderbook']._options = None
  _QUERY.methods_by_name['DerivativeOrderbook']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/derivative/orderbook/{market_id}'
  _QUERY.methods_by_name['TraderDerivativeOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeOrders']._serialized_options = b'\202\323\344\223\002K\022I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['DerivativeOrdersByHashes']._options = None
  _QUERY.methods_by_name['DerivativeOrdersByHashes']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['TraderDerivativeTransientOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeTransientOrders']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['DerivativeMarkets']._options = None
  _QUERY.methods_by_name['DerivativeMarkets']._serialized_options = b'\202\323\344\223\0020\022./injective/exchange/v1beta1/derivative/markets'
  _QUERY.methods_by_name['DerivativeMarket']._options = None
  _QUERY.methods_by_name['DerivativeMarket']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/derivative/markets/{market_id}'
  _QUERY.methods_by_name['DerivativeMarketAddress']._options = None
  _QUERY.methods_by_name['DerivativeMarketAddress']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/derivative/market_address/{market_id}'
  _QUERY.methods_by_name['SubaccountTradeNonce']._options = None
  _QUERY.methods_by_name['SubaccountTradeNonce']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/exchange/{subaccount_id}'
  _QUERY.methods_by_name['ExchangeModuleState']._options = None
  _QUERY.methods_by_name['ExchangeModuleState']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/module_state'
  _QUERY.methods_by_name['Positions']._options = None
  _QUERY.methods_by_name['Positions']._serialized_options = b'\202\323\344\223\002\'\022%/injective/exchange/v1beta1/positions'
  _QUERY.methods_by_name['SubaccountPositions']._options = None
  _QUERY.methods_by_name['SubaccountPositions']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/positions/{subaccount_id}'
  _QUERY.methods_by_name['SubaccountPositionInMarket']._options = None
  _QUERY.methods_by_name['SubaccountPositionInMarket']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}'
  _QUERY.methods_by_name['SubaccountEffectivePositionInMarket']._options = None
  _QUERY.methods_by_name['SubaccountEffectivePositionInMarket']._serialized_options = b'\202\323\344\223\002M\022K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}'
  _QUERY.methods_by_name['PerpetualMarketInfo']._options = None
  _QUERY.methods_by_name['PerpetualMarketInfo']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/perpetual_market_info/{market_id}'
  _QUERY.methods_by_name['ExpiryFuturesMarketInfo']._options = None
  _QUERY.methods_by_name['ExpiryFuturesMarketInfo']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/expiry_market_info/{market_id}'
  _QUERY.methods_by_name['PerpetualMarketFunding']._options = None
  _QUERY.methods_by_name['PerpetualMarketFunding']._serialized_options = b'\202\323\344\223\002B\022@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}'
  _QUERY.methods_by_name['SubaccountOrderMetadata']._options = None
  _QUERY.methods_by_name['SubaccountOrderMetadata']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/order_metadata/{subaccount_id}'
  _QUERY.methods_by_name['TradeRewardPoints']._options = None
  _QUERY.methods_by_name['TradeRewardPoints']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v1beta1/trade_reward_points'
  _QUERY.methods_by_name['PendingTradeRewardPoints']._options = None
  _QUERY.methods_by_name['PendingTradeRewardPoints']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/pending_trade_reward_points'
  _QUERY.methods_by_name['TradeRewardCampaign']._options = None
  _QUERY.methods_by_name['TradeRewardCampaign']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/trade_reward_campaign'
  _QUERY.methods_by_name['FeeDiscountAccountInfo']._options = None
  _QUERY.methods_by_name['FeeDiscountAccountInfo']._serialized_options = b'\202\323\344\223\002A\022?/injective/exchange/v1beta1/fee_discount_account_info/{account}'
  _QUERY.methods_by_name['FeeDiscountSchedule']._options = None
  _QUERY.methods_by_name['FeeDiscountSchedule']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/fee_discount_schedule'
  _QUERY.methods_by_name['BalanceMismatches']._options = None
  _QUERY.methods_by_name['BalanceMismatches']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/balance_mismatches/{dust_factor}'
  _QUERY.methods_by_name['BalanceWithBalanceHolds']._options = None
  _QUERY.methods_by_name['BalanceWithBalanceHolds']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/balances_with_balance_holds'
  _QUERY.methods_by_name['FeeDiscountTierStatistics']._options = None
  _QUERY.methods_by_name['FeeDiscountTierStatistics']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/fee_discount_tier_stats'
  _QUERY.methods_by_name['MitoVaultInfos']._options = None
  _QUERY.methods_by_name['MitoVaultInfos']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v1beta1/mito_vault_infos'
  _QUERY.methods_by_name['QueryMarketIDFromVault']._options = None
  _QUERY.methods_by_name['QueryMarketIDFromVault']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/vault_market_id/{vault_subaccount_id}'
  _QUERY.methods_by_name['HistoricalTradeRecords']._options = None
  _QUERY.methods_by_name['HistoricalTradeRecords']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/historical_trade_records'
  _QUERY.methods_by_name['IsOptedOutOfRewards']._options = None
  _QUERY.methods_by_name['IsOptedOutOfRewards']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}'
  _QUERY.methods_by_name['OptedOutOfRewardsAccounts']._options = None
  _QUERY.methods_by_name['OptedOutOfRewardsAccounts']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/opted_out_of_rewards_accounts'
  _QUERY.methods_by_name['MarketVolatility']._options = None
  _QUERY.methods_by_name['MarketVolatility']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/market_volatility/{market_id}'
  _QUERY.methods_by_name['BinaryOptionsMarkets']._options = None
  _QUERY.methods_by_name['BinaryOptionsMarkets']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/binary_options/markets'
  _QUERY.methods_by_name['TraderDerivativeConditionalOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeConditionalOrders']._serialized_options = b'\202\323\344\223\002W\022U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['MarketAtomicExecutionFeeMultiplier']._options = None
  _QUERY.methods_by_name['MarketAtomicExecutionFeeMultiplier']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/atomic_order_fee_multiplier'
  _CANCELLATIONSTRATEGY._serialized_start=13085
  _CANCELLATIONSTRATEGY._serialized_end=13171
  _SUBACCOUNT._serialized_start=246
  _SUBACCOUNT._serialized_end=300
  _QUERYSUBACCOUNTORDERSREQUEST._serialized_start=302
  _QUERYSUBACCOUNTORDERSREQUEST._serialized_end=374
  _QUERYSUBACCOUNTORDERSRESPONSE._serialized_start=377
  _QUERYSUBACCOUNTORDERSRESPONSE._serialized_end=547
  _SUBACCOUNTORDERBOOKMETADATAWITHMARKET._serialized_start=550
  _SUBACCOUNTORDERBOOKMETADATAWITHMARKET._serialized_end=698
  _QUERYEXCHANGEPARAMSREQUEST._serialized_start=700
  _QUERYEXCHANGEPARAMSREQUEST._serialized_end=728
  _QUERYEXCHANGEPARAMSRESPONSE._serialized_start=730
  _QUERYEXCHANGEPARAMSRESPONSE._serialized_end=817
  _QUERYSUBACCOUNTDEPOSITSREQUEST._serialized_start=819
  _QUERYSUBACCOUNTDEPOSITSREQUEST._serialized_end=940
  _QUERYSUBACCOUNTDEPOSITSRESPONSE._serialized_start=943
  _QUERYSUBACCOUNTDEPOSITSRESPONSE._serialized_end=1155
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._serialized_start=1071
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._serialized_end=1155
  _QUERYEXCHANGEBALANCESREQUEST._serialized_start=1157
  _QUERYEXCHANGEBALANCESREQUEST._serialized_end=1187
  _QUERYEXCHANGEBALANCESRESPONSE._serialized_start=1189
  _QUERYEXCHANGEBALANCESRESPONSE._serialized_end=1281
  _QUERYAGGREGATEVOLUMEREQUEST._serialized_start=1283
  _QUERYAGGREGATEVOLUMEREQUEST._serialized_end=1329
  _QUERYAGGREGATEVOLUMERESPONSE._serialized_start=1331
  _QUERYAGGREGATEVOLUMERESPONSE._serialized_end=1430
  _QUERYAGGREGATEVOLUMESREQUEST._serialized_start=1432
  _QUERYAGGREGATEVOLUMESREQUEST._serialized_end=1500
  _QUERYAGGREGATEVOLUMESRESPONSE._serialized_start=1503
  _QUERYAGGREGATEVOLUMESRESPONSE._serialized_end=1703
  _QUERYAGGREGATEMARKETVOLUMEREQUEST._serialized_start=1705
  _QUERYAGGREGATEMARKETVOLUMEREQUEST._serialized_end=1759
  _QUERYAGGREGATEMARKETVOLUMERESPONSE._serialized_start=1761
  _QUERYAGGREGATEMARKETVOLUMERESPONSE._serialized_end=1861
  _QUERYDENOMDECIMALREQUEST._serialized_start=1863
  _QUERYDENOMDECIMALREQUEST._serialized_end=1904
  _QUERYDENOMDECIMALRESPONSE._serialized_start=1906
  _QUERYDENOMDECIMALRESPONSE._serialized_end=1950
  _QUERYDENOMDECIMALSREQUEST._serialized_start=1952
  _QUERYDENOMDECIMALSREQUEST._serialized_end=1995
  _QUERYDENOMDECIMALSRESPONSE._serialized_start=1997
  _QUERYDENOMDECIMALSRESPONSE._serialized_end=2098
  _QUERYAGGREGATEMARKETVOLUMESREQUEST._serialized_start=2100
  _QUERYAGGREGATEMARKETVOLUMESREQUEST._serialized_end=2156
  _QUERYAGGREGATEMARKETVOLUMESRESPONSE._serialized_start=2158
  _QUERYAGGREGATEMARKETVOLUMESRESPONSE._serialized_end=2254
  _QUERYSUBACCOUNTDEPOSITREQUEST._serialized_start=2256
  _QUERYSUBACCOUNTDEPOSITREQUEST._serialized_end=2325
  _QUERYSUBACCOUNTDEPOSITRESPONSE._serialized_start=2327
  _QUERYSUBACCOUNTDEPOSITRESPONSE._serialized_end=2414
  _QUERYSPOTMARKETSREQUEST._serialized_start=2416
  _QUERYSPOTMARKETSREQUEST._serialized_end=2457
  _QUERYSPOTMARKETSRESPONSE._serialized_start=2459
  _QUERYSPOTMARKETSRESPONSE._serialized_end=2542
  _QUERYSPOTMARKETREQUEST._serialized_start=2544
  _QUERYSPOTMARKETREQUEST._serialized_end=2587
  _QUERYSPOTMARKETRESPONSE._serialized_start=2589
  _QUERYSPOTMARKETRESPONSE._serialized_end=2670
  _QUERYSPOTORDERBOOKREQUEST._serialized_start=2672
  _QUERYSPOTORDERBOOKREQUEST._serialized_end=2733
  _QUERYSPOTORDERBOOKRESPONSE._serialized_start=2736
  _QUERYSPOTORDERBOOKRESPONSE._serialized_end=2887
  _QUERYSPOTORDERSBYHASHESREQUEST._serialized_start=2889
  _QUERYSPOTORDERSBYHASHESREQUEST._serialized_end=2985
  _QUERYSPOTORDERSBYHASHESRESPONSE._serialized_start=2987
  _QUERYSPOTORDERSBYHASHESRESPONSE._serialized_end=3087
  _QUERYTRADERSPOTORDERSREQUEST._serialized_start=3089
  _QUERYTRADERSPOTORDERSREQUEST._serialized_end=3161
  _TRIMMEDSPOTLIMITORDER._serialized_start=3164
  _TRIMMEDSPOTLIMITORDER._serialized_end=3417
  _QUERYTRADERSPOTORDERSRESPONSE._serialized_start=3419
  _QUERYTRADERSPOTORDERSRESPONSE._serialized_end=3517
  _QUERYSPOTMIDPRICEANDTOBREQUEST._serialized_start=3519
  _QUERYSPOTMIDPRICEANDTOBREQUEST._serialized_end=3570
  _QUERYSPOTMIDPRICEANDTOBRESPONSE._serialized_start=3573
  _QUERYSPOTMIDPRICEANDTOBRESPONSE._serialized_end=3818
  _QUERYDERIVATIVEMIDPRICEANDTOBREQUEST._serialized_start=3820
  _QUERYDERIVATIVEMIDPRICEANDTOBREQUEST._serialized_end=3877
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE._serialized_start=3880
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE._serialized_end=4131
  _QUERYDERIVATIVEORDERBOOKREQUEST._serialized_start=4133
  _QUERYDERIVATIVEORDERBOOKREQUEST._serialized_end=4200
  _QUERYDERIVATIVEORDERBOOKRESPONSE._serialized_start=4203
  _QUERYDERIVATIVEORDERBOOKRESPONSE._serialized_end=4360
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST._serialized_start=4363
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST._serialized_end=4733
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST._serialized_start=4736
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST._serialized_end=5043
  _QUERYTRADERDERIVATIVEORDERSREQUEST._serialized_start=5045
  _QUERYTRADERDERIVATIVEORDERSREQUEST._serialized_end=5123
  _TRIMMEDDERIVATIVELIMITORDER._serialized_start=5126
  _TRIMMEDDERIVATIVELIMITORDER._serialized_end=5460
  _QUERYTRADERDERIVATIVEORDERSRESPONSE._serialized_start=5462
  _QUERYTRADERDERIVATIVEORDERSRESPONSE._serialized_end=5572
  _QUERYDERIVATIVEORDERSBYHASHESREQUEST._serialized_start=5574
  _QUERYDERIVATIVEORDERSBYHASHESREQUEST._serialized_end=5676
  _QUERYDERIVATIVEORDERSBYHASHESRESPONSE._serialized_start=5678
  _QUERYDERIVATIVEORDERSBYHASHESRESPONSE._serialized_end=5790
  _QUERYDERIVATIVEMARKETSREQUEST._serialized_start=5792
  _QUERYDERIVATIVEMARKETSREQUEST._serialized_end=5839
  _PRICELEVEL._serialized_start=5842
  _PRICELEVEL._serialized_end=5983
  _PERPETUALMARKETSTATE._serialized_start=5986
  _PERPETUALMARKETSTATE._serialized_end=6152
  _FULLDERIVATIVEMARKET._serialized_start=6155
  _FULLDERIVATIVEMARKET._serialized_end=6468
  _QUERYDERIVATIVEMARKETSRESPONSE._serialized_start=6470
  _QUERYDERIVATIVEMARKETSRESPONSE._serialized_end=6569
  _QUERYDERIVATIVEMARKETREQUEST._serialized_start=6571
  _QUERYDERIVATIVEMARKETREQUEST._serialized_end=6620
  _QUERYDERIVATIVEMARKETRESPONSE._serialized_start=6622
  _QUERYDERIVATIVEMARKETRESPONSE._serialized_end=6719
  _QUERYDERIVATIVEMARKETADDRESSREQUEST._serialized_start=6721
  _QUERYDERIVATIVEMARKETADDRESSREQUEST._serialized_end=6777
  _QUERYDERIVATIVEMARKETADDRESSRESPONSE._serialized_start=6779
  _QUERYDERIVATIVEMARKETADDRESSRESPONSE._serialized_end=6857
  _QUERYSUBACCOUNTTRADENONCEREQUEST._serialized_start=6859
  _QUERYSUBACCOUNTTRADENONCEREQUEST._serialized_end=6916
  _QUERYSUBACCOUNTPOSITIONSREQUEST._serialized_start=6918
  _QUERYSUBACCOUNTPOSITIONSREQUEST._serialized_end=6974
  _QUERYSUBACCOUNTPOSITIONINMARKETREQUEST._serialized_start=6976
  _QUERYSUBACCOUNTPOSITIONINMARKETREQUEST._serialized_end=7058
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST._serialized_start=7060
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST._serialized_end=7151
  _QUERYSUBACCOUNTORDERMETADATAREQUEST._serialized_start=7153
  _QUERYSUBACCOUNTORDERMETADATAREQUEST._serialized_end=7213
  _QUERYSUBACCOUNTPOSITIONSRESPONSE._serialized_start=7215
  _QUERYSUBACCOUNTPOSITIONSRESPONSE._serialized_end=7318
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE._serialized_start=7320
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE._serialized_end=7420
  _EFFECTIVEPOSITION._serialized_start=7423
  _EFFECTIVEPOSITION._serialized_end=7668
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE._serialized_start=7670
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE._serialized_end=7788
  _QUERYPERPETUALMARKETINFOREQUEST._serialized_start=7790
  _QUERYPERPETUALMARKETINFOREQUEST._serialized_end=7842
  _QUERYPERPETUALMARKETINFORESPONSE._serialized_start=7844
  _QUERYPERPETUALMARKETINFORESPONSE._serialized_end=7947
  _QUERYEXPIRYFUTURESMARKETINFOREQUEST._serialized_start=7949
  _QUERYEXPIRYFUTURESMARKETINFOREQUEST._serialized_end=8005
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE._serialized_start=8007
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE._serialized_end=8118
  _QUERYPERPETUALMARKETFUNDINGREQUEST._serialized_start=8120
  _QUERYPERPETUALMARKETFUNDINGREQUEST._serialized_end=8175
  _QUERYPERPETUALMARKETFUNDINGRESPONSE._serialized_start=8177
  _QUERYPERPETUALMARKETFUNDINGRESPONSE._serialized_end=8287
  _QUERYSUBACCOUNTORDERMETADATARESPONSE._serialized_start=8290
  _QUERYSUBACCOUNTORDERMETADATARESPONSE._serialized_end=8419
  _QUERYSUBACCOUNTTRADENONCERESPONSE._serialized_start=8421
  _QUERYSUBACCOUNTTRADENONCERESPONSE._serialized_end=8471
  _QUERYMODULESTATEREQUEST._serialized_start=8473
  _QUERYMODULESTATEREQUEST._serialized_end=8498
  _QUERYMODULESTATERESPONSE._serialized_start=8500
  _QUERYMODULESTATERESPONSE._serialized_end=8583
  _QUERYPOSITIONSREQUEST._serialized_start=8585
  _QUERYPOSITIONSREQUEST._serialized_end=8608
  _QUERYPOSITIONSRESPONSE._serialized_start=8610
  _QUERYPOSITIONSRESPONSE._serialized_end=8703
  _QUERYTRADEREWARDPOINTSREQUEST._serialized_start=8705
  _QUERYTRADEREWARDPOINTSREQUEST._serialized_end=8786
  _QUERYTRADEREWARDPOINTSRESPONSE._serialized_start=8788
  _QUERYTRADEREWARDPOINTSRESPONSE._serialized_end=8905
  _QUERYTRADEREWARDCAMPAIGNREQUEST._serialized_start=8907
  _QUERYTRADEREWARDCAMPAIGNREQUEST._serialized_end=8940
  _QUERYTRADEREWARDCAMPAIGNRESPONSE._serialized_start=8943
  _QUERYTRADEREWARDCAMPAIGNRESPONSE._serialized_end=9442
  _QUERYISOPTEDOUTOFREWARDSREQUEST._serialized_start=9444
  _QUERYISOPTEDOUTOFREWARDSREQUEST._serialized_end=9494
  _QUERYISOPTEDOUTOFREWARDSRESPONSE._serialized_start=9496
  _QUERYISOPTEDOUTOFREWARDSRESPONSE._serialized_end=9552
  _QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST._serialized_start=9554
  _QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST._serialized_end=9593
  _QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE._serialized_start=9595
  _QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE._serialized_end=9653
  _QUERYFEEDISCOUNTACCOUNTINFOREQUEST._serialized_start=9655
  _QUERYFEEDISCOUNTACCOUNTINFOREQUEST._serialized_end=9708
  _QUERYFEEDISCOUNTACCOUNTINFORESPONSE._serialized_start=9711
  _QUERYFEEDISCOUNTACCOUNTINFORESPONSE._serialized_end=9908
  _QUERYFEEDISCOUNTSCHEDULEREQUEST._serialized_start=9910
  _QUERYFEEDISCOUNTSCHEDULEREQUEST._serialized_end=9943
  _QUERYFEEDISCOUNTSCHEDULERESPONSE._serialized_start=9945
  _QUERYFEEDISCOUNTSCHEDULERESPONSE._serialized_end=10059
  _QUERYBALANCEMISMATCHESREQUEST._serialized_start=10061
  _QUERYBALANCEMISMATCHESREQUEST._serialized_end=10113
  _BALANCEMISMATCH._serialized_start=10116
  _BALANCEMISMATCH._serialized_end=10510
  _QUERYBALANCEMISMATCHESRESPONSE._serialized_start=10512
  _QUERYBALANCEMISMATCHESRESPONSE._serialized_end=10617
  _QUERYBALANCEWITHBALANCEHOLDSREQUEST._serialized_start=10619
  _QUERYBALANCEWITHBALANCEHOLDSREQUEST._serialized_end=10656
  _BALANCEWITHMARGINHOLD._serialized_start=10659
  _BALANCEWITHMARGINHOLD._serialized_end=10919
  _QUERYBALANCEWITHBALANCEHOLDSRESPONSE._serialized_start=10921
  _QUERYBALANCEWITHBALANCEHOLDSRESPONSE._serialized_end=11046
  _QUERYFEEDISCOUNTTIERSTATISTICSREQUEST._serialized_start=11048
  _QUERYFEEDISCOUNTTIERSTATISTICSREQUEST._serialized_end=11087
  _TIERSTATISTIC._serialized_start=11089
  _TIERSTATISTIC._serialized_end=11133
  _QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE._serialized_start=11135
  _QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE._serialized_end=11238
  _MITOVAULTINFOSREQUEST._serialized_start=11240
  _MITOVAULTINFOSREQUEST._serialized_end=11263
  _MITOVAULTINFOSRESPONSE._serialized_start=11266
  _MITOVAULTINFOSRESPONSE._serialized_end=11394
  _QUERYMARKETIDFROMVAULTREQUEST._serialized_start=11396
  _QUERYMARKETIDFROMVAULTREQUEST._serialized_end=11456
  _QUERYMARKETIDFROMVAULTRESPONSE._serialized_start=11458
  _QUERYMARKETIDFROMVAULTRESPONSE._serialized_end=11509
  _QUERYHISTORICALTRADERECORDSREQUEST._serialized_start=11511
  _QUERYHISTORICALTRADERECORDSREQUEST._serialized_end=11566
  _QUERYHISTORICALTRADERECORDSRESPONSE._serialized_start=11568
  _QUERYHISTORICALTRADERECORDSRESPONSE._serialized_end=11670
  _TRADEHISTORYOPTIONS._serialized_start=11672
  _TRADEHISTORYOPTIONS._serialized_end=11793
  _QUERYMARKETVOLATILITYREQUEST._serialized_start=11796
  _QUERYMARKETVOLATILITYREQUEST._serialized_end=11925
  _QUERYMARKETVOLATILITYRESPONSE._serialized_start=11928
  _QUERYMARKETVOLATILITYRESPONSE._serialized_end=12157
  _QUERYBINARYMARKETSREQUEST._serialized_start=12159
  _QUERYBINARYMARKETSREQUEST._serialized_end=12202
  _QUERYBINARYMARKETSRESPONSE._serialized_start=12204
  _QUERYBINARYMARKETSRESPONSE._serialized_end=12298
  _QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST._serialized_start=12300
  _QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST._serialized_end=12389
  _TRIMMEDDERIVATIVECONDITIONALORDER._serialized_start=12392
  _TRIMMEDDERIVATIVECONDITIONALORDER._serialized_end=12766
  _QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE._serialized_start=12768
  _QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE._serialized_end=12895
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST._serialized_start=12897
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST._serialized_end=12964
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE._serialized_start=12966
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE._serialized_end=13083
  _QUERY._serialized_start=13174
  _QUERY._serialized_end=24635
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_ext.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/types/v1beta1/tx_ext.proto\x12\x17injective.types.v1beta1\x1a\x14gogoproto/gogo.proto\"_\n\x16\x45xtensionOptionsWeb3Tx\x12\x18\n\x10typedDataChainID\x18\x01 \x01(\x04\x12\x10\n\x08\x66\x65\x65Payer\x18\x02 \x01(\t\x12\x13\n\x0b\x66\x65\x65PayerSig\x18\x03 \x01(\x0c:\x04\x88\xa0\x1f\x00\x42?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_ext_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types'
  _EXTENSIONOPTIONSWEB3TX._options = None
  _EXTENSIONOPTIONSWEB3TX._serialized_options = b'\210\240\037\000'
  _EXTENSIONOPTIONSWEB3TX._serialized_start=87
  _EXTENSIONOPTIONSWEB3TX._serialized_end=182
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/evidence/v1beta1/tx.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"f\n\x11MsgSubmitEvidence\x12\x11\n\tsubmitter\x18\x01 \x01(\t\x12\x34\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08\x45vidence:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\")\n\x19MsgSubmitEvidenceResponse\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x32w\n\x03Msg\x12p\n\x0eSubmitEvidence\x12*.cosmos.evidence.v1beta1.MsgSubmitEvidence\x1a\x32.cosmos.evidence.v1beta1.MsgSubmitEvidenceResponseB3Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\250\342\036\001'
  _MSGSUBMITEVIDENCE.fields_by_name['evidence']._options = None
  _MSGSUBMITEVIDENCE.fields_by_name['evidence']._serialized_options = b'\312\264-\010Evidence'
  _MSGSUBMITEVIDENCE._options = None
  _MSGSUBMITEVIDENCE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSUBMITEVIDENCE._serialized_start=137
  _MSGSUBMITEVIDENCE._serialized_end=239
  _MSGSUBMITEVIDENCERESPONSE._serialized_start=241
  _MSGSUBMITEVIDENCERESPONSE._serialized_end=282
  _MSG._serialized_start=284
  _MSG._serialized_end=403
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/ocr/v1beta1/tx.proto\x12\x15injective.ocr.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\\\n\rMsgCreateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgCreateFeedResponse\"\xbd\x02\n\rMsgUpdateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12L\n\x14link_per_observation\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12M\n\x15link_per_transmission\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12\x12\n\nlink_denom\x18\x07 \x01(\t\x12\x12\n\nfeed_admin\x18\x08 \x01(\t\x12\x15\n\rbilling_admin\x18\t \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUpdateFeedResponse\"\xc9\x01\n\x0bMsgTransmit\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\x12\x15\n\rconfig_digest\x18\x02 \x01(\x0c\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\r\n\x05\x65poch\x18\x04 \x01(\x04\x12\r\n\x05round\x18\x05 \x01(\x04\x12\x12\n\nextra_hash\x18\x06 \x01(\x0c\x12-\n\x06report\x18\x07 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.Report\x12\x12\n\nsignatures\x18\x08 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgTransmitResponse\"s\n\x15MsgFundFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgFundFeedRewardPoolResponse\"w\n\x19MsgWithdrawFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"#\n!MsgWithdrawFeedRewardPoolResponse\"_\n\x0cMsgSetPayees\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\x0e\n\x06payees\x18\x04 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x16\n\x14MsgSetPayeesResponse\"h\n\x14MsgTransferPayeeship\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\x10\n\x08proposed\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgTransferPayeeshipResponse\"S\n\x12MsgAcceptPayeeship\x12\r\n\x05payee\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgAcceptPayeeshipResponse2\xed\x06\n\x03Msg\x12`\n\nCreateFeed\x12$.injective.ocr.v1beta1.MsgCreateFeed\x1a,.injective.ocr.v1beta1.MsgCreateFeedResponse\x12`\n\nUpdateFeed\x12$.injective.ocr.v1beta1.MsgUpdateFeed\x1a,.injective.ocr.v1beta1.MsgUpdateFeedResponse\x12Z\n\x08Transmit\x12\".injective.ocr.v1beta1.MsgTransmit\x1a*.injective.ocr.v1beta1.MsgTransmitResponse\x12x\n\x12\x46undFeedRewardPool\x12,.injective.ocr.v1beta1.MsgFundFeedRewardPool\x1a\x34.injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse\x12\x84\x01\n\x16WithdrawFeedRewardPool\x12\x30.injective.ocr.v1beta1.MsgWithdrawFeedRewardPool\x1a\x38.injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse\x12]\n\tSetPayees\x12#.injective.ocr.v1beta1.MsgSetPayees\x1a+.injective.ocr.v1beta1.MsgSetPayeesResponse\x12u\n\x11TransferPayeeship\x12+.injective.ocr.v1beta1.MsgTransferPayeeship\x1a\x33.injective.ocr.v1beta1.MsgTransferPayeeshipResponse\x12o\n\x0f\x41\x63\x63\x65ptPayeeship\x12).injective.ocr.v1beta1.MsgAcceptPayeeship\x1a\x31.injective.ocr.v1beta1.MsgAcceptPayeeshipResponseBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _MSGCREATEFEED._options = None
  _MSGCREATEFEED._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGUPDATEFEED.fields_by_name['link_per_observation']._options = None
  _MSGUPDATEFEED.fields_by_name['link_per_observation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001'
  _MSGUPDATEFEED.fields_by_name['link_per_transmission']._options = None
  _MSGUPDATEFEED.fields_by_name['link_per_transmission']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001'
  _MSGUPDATEFEED._options = None
  _MSGUPDATEFEED._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTRANSMIT._options = None
  _MSGTRANSMIT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGFUNDFEEDREWARDPOOL.fields_by_name['amount']._options = None
  _MSGFUNDFEEDREWARDPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGFUNDFEEDREWARDPOOL._options = None
  _MSGFUNDFEEDREWARDPOOL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount']._options = None
  _MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGWITHDRAWFEEDREWARDPOOL._options = None
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSETPAYEES._options = None
  _MSGSETPAYEES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTRANSFERPAYEESHIP._options = None
  _MSGTRANSFERPAYEESHIP._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGACCEPTPAYEESHIP._options = None
  _MSGACCEPTPAYEESHIP._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEFEED._serialized_start=144
  _MSGCREATEFEED._serialized_end=236
  _MSGCREATEFEEDRESPONSE._serialized_start=238
  _MSGCREATEFEEDRESPONSE._serialized_end=261
  _MSGUPDATEFEED._serialized_start=264
  _MSGUPDATEFEED._serialized_end=581
  _MSGUPDATEFEEDRESPONSE._serialized_start=583
  _MSGUPDATEFEEDRESPONSE._serialized_end=606
  _MSGTRANSMIT._serialized_start=609
  _MSGTRANSMIT._serialized_end=810
  _MSGTRANSMITRESPONSE._serialized_start=812
  _MSGTRANSMITRESPONSE._serialized_end=833
  _MSGFUNDFEEDREWARDPOOL._serialized_start=835
  _MSGFUNDFEEDREWARDPOOL._serialized_end=950
  _MSGFUNDFEEDREWARDPOOLRESPONSE._serialized_start=952
  _MSGFUNDFEEDREWARDPOOLRESPONSE._serialized_end=983
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_start=985
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_end=1104
  _MSGWITHDRAWFEEDREWARDPOOLRESPONSE._serialized_start=1106
  _MSGWITHDRAWFEEDREWARDPOOLRESPONSE._serialized_end=1141
  _MSGSETPAYEES._serialized_start=1143
  _MSGSETPAYEES._serialized_end=1238
  _MSGSETPAYEESRESPONSE._serialized_start=1240
  _MSGSETPAYEESRESPONSE._serialized_end=1262
  _MSGTRANSFERPAYEESHIP._serialized_start=1264
  _MSGTRANSFERPAYEESHIP._serialized_end=1368
  _MSGTRANSFERPAYEESHIPRESPONSE._serialized_start=1370
  _MSGTRANSFERPAYEESHIPRESPONSE._serialized_end=1400
  _MSGACCEPTPAYEESHIP._serialized_start=1402
  _MSGACCEPTPAYEESHIP._serialized_end=1485
  _MSGACCEPTPAYEESHIPRESPONSE._serialized_start=1487
  _MSGACCEPTPAYEESHIPRESPONSE._serialized_end=1515
  _MSG._serialized_start=1518
  _MSG._serialized_end=2395
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_exchange_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_exchange_rpc.proto\x12\x16injective_exchange_rpc\"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x92\x01\n\rGetTxResponse\x12\x0f\n\x07tx_hash\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x12\x12\r\n\x05index\x18\x03 \x01(\r\x12\x11\n\tcodespace\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0f\n\x07raw_log\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\t\"\xb4\x01\n\x10PrepareTxRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\x04\x12\x16\n\x0esigner_address\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x0c\n\x04memo\x18\x04 \x01(\t\x12\x16\n\x0etimeout_height\x18\x05 \x01(\x04\x12\x30\n\x03\x66\x65\x65\x18\x06 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFee\x12\x0c\n\x04msgs\x18\x07 \x03(\x0c\"c\n\x0b\x43osmosTxFee\x12\x31\n\x05price\x18\x01 \x03(\x0b\x32\".injective_exchange_rpc.CosmosCoin\x12\x0b\n\x03gas\x18\x02 \x01(\x04\x12\x14\n\x0c\x64\x65legate_fee\x18\x03 \x01(\x08\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x86\x01\n\x11PrepareTxResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x11\n\tsign_mode\x18\x03 \x01(\t\x12\x14\n\x0cpub_key_type\x18\x04 \x01(\t\x12\x11\n\tfee_payer\x18\x05 \x01(\t\x12\x15\n\rfee_payer_sig\x18\x06 \x01(\t\"\xc2\x01\n\x12\x42roadcastTxRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\x04\x12\n\n\x02tx\x18\x02 \x01(\x0c\x12\x0c\n\x04msgs\x18\x03 \x03(\x0c\x12\x35\n\x07pub_key\x18\x04 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKey\x12\x11\n\tsignature\x18\x05 \x01(\t\x12\x11\n\tfee_payer\x18\x06 \x01(\t\x12\x15\n\rfee_payer_sig\x18\x07 \x01(\t\x12\x0c\n\x04mode\x18\x08 \x01(\t\")\n\x0c\x43osmosPubKey\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x98\x01\n\x13\x42roadcastTxResponse\x12\x0f\n\x07tx_hash\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x12\x12\r\n\x05index\x18\x03 \x01(\r\x12\x11\n\tcodespace\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0f\n\x07raw_log\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\t\"\xa8\x01\n\x16PrepareCosmosTxRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\x04\x12\x16\n\x0esender_address\x18\x02 \x01(\t\x12\x0c\n\x04memo\x18\x03 \x01(\t\x12\x16\n\x0etimeout_height\x18\x04 \x01(\x04\x12\x30\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFee\x12\x0c\n\x04msgs\x18\x06 \x03(\x0c\"\xb9\x01\n\x17PrepareCosmosTxResponse\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12\x11\n\tsign_mode\x18\x02 \x01(\t\x12\x14\n\x0cpub_key_type\x18\x03 \x01(\t\x12\x11\n\tfee_payer\x18\x04 \x01(\t\x12\x15\n\rfee_payer_sig\x18\x05 \x01(\t\x12?\n\x11\x66\x65\x65_payer_pub_key\x18\x06 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKey\"\x88\x01\n\x18\x42roadcastCosmosTxRequest\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12\x35\n\x07pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKey\x12\x11\n\tsignature\x18\x03 \x01(\t\x12\x16\n\x0esender_address\x18\x04 \x01(\t\"\x9e\x01\n\x19\x42roadcastCosmosTxResponse\x12\x0f\n\x07tx_hash\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x12\x12\r\n\x05index\x18\x03 \x01(\r\x12\x11\n\tcodespace\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0f\n\x07raw_log\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\t\"\x14\n\x12GetFeePayerRequest\"i\n\x13GetFeePayerResponse\x12\x11\n\tfee_payer\x18\x01 \x01(\t\x12?\n\x11\x66\x65\x65_payer_pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKey2\x8c\x05\n\x14InjectiveExchangeRPC\x12T\n\x05GetTx\x12$.injective_exchange_rpc.GetTxRequest\x1a%.injective_exchange_rpc.GetTxResponse\x12`\n\tPrepareTx\x12(.injective_exchange_rpc.PrepareTxRequest\x1a).injective_exchange_rpc.PrepareTxResponse\x12\x66\n\x0b\x42roadcastTx\x12*.injective_exchange_rpc.BroadcastTxRequest\x1a+.injective_exchange_rpc.BroadcastTxResponse\x12r\n\x0fPrepareCosmosTx\x12..injective_exchange_rpc.PrepareCosmosTxRequest\x1a/.injective_exchange_rpc.PrepareCosmosTxResponse\x12x\n\x11\x42roadcastCosmosTx\x12\x30.injective_exchange_rpc.BroadcastCosmosTxRequest\x1a\x31.injective_exchange_rpc.BroadcastCosmosTxResponse\x12\x66\n\x0bGetFeePayer\x12*.injective_exchange_rpc.GetFeePayerRequest\x1a+.injective_exchange_rpc.GetFeePayerResponseB\x1bZ\x19/injective_exchange_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_exchange_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_exchange_rpcpb'
  _GETTXREQUEST._serialized_start=65
  _GETTXREQUEST._serialized_end=93
  _GETTXRESPONSE._serialized_start=96
  _GETTXRESPONSE._serialized_end=242
  _PREPARETXREQUEST._serialized_start=245
  _PREPARETXREQUEST._serialized_end=425
  _COSMOSTXFEE._serialized_start=427
  _COSMOSTXFEE._serialized_end=526
  _COSMOSCOIN._serialized_start=528
  _COSMOSCOIN._serialized_end=571
  _PREPARETXRESPONSE._serialized_start=574
  _PREPARETXRESPONSE._serialized_end=708
  _BROADCASTTXREQUEST._serialized_start=711
  _BROADCASTTXREQUEST._serialized_end=905
  _COSMOSPUBKEY._serialized_start=907
  _COSMOSPUBKEY._serialized_end=948
  _BROADCASTTXRESPONSE._serialized_start=951
  _BROADCASTTXRESPONSE._serialized_end=1103
  _PREPARECOSMOSTXREQUEST._serialized_start=1106
  _PREPARECOSMOSTXREQUEST._serialized_end=1274
  _PREPARECOSMOSTXRESPONSE._serialized_start=1277
  _PREPARECOSMOSTXRESPONSE._serialized_end=1462
  _BROADCASTCOSMOSTXREQUEST._serialized_start=1465
  _BROADCASTCOSMOSTXREQUEST._serialized_end=1601
  _BROADCASTCOSMOSTXRESPONSE._serialized_start=1604
  _BROADCASTCOSMOSTXRESPONSE._serialized_end=1762
  _GETFEEPAYERREQUEST._serialized_start=1764
  _GETFEEPAYERREQUEST._serialized_end=1784
  _GETFEEPAYERRESPONSE._serialized_start=1786
  _GETFEEPAYERRESPONSE._serialized_end=1891
  _INJECTIVEEXCHANGERPC._serialized_start=1894
  _INJECTIVEEXCHANGERPC._serialized_end=2546
# @@protoc_insertion_point(module_scope)
